function [R,Z,f] = plotRZLineal(N,beta,a,b,tau0)
%function [R,Z,f] = CartaRZInf(N,beta,a,b,tau0,L) nos va a generar una carta de puntos (R,Z) en el instante que yo le diga
%utilizando como parametros:

%   N:     Numero de puntos a utilizar
%   beta:  Parametro beta de la gaussiana que vamos a utilizar como perfil.
%   a:     Hace referencia a la altura maxima del cilindro
%   b:     Hace referencia a la distancia radial maxima del sistema que vamos a estudiar
%   tau0:  Instante en el que voy a considerar el campo escalar de temperaturas.

%En este primer programa tomamos el perfil de temperaturas en el instante inicial como independiente de Z y theta. La dependencia
%radial de dicha distribucion la estamos suponiendo gaussiana de parametro beta.

    [Am,betam] = coefAs(N,beta,b);
    
%Temperaturas o niveles de temperatura que estamos buscando

    v = [1.0,0.9,0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0];
    
%Veamos los parametros asociados al experimento. Las temperaturas se miden en ºC

    Tint = 60;
    Text = -150;
    Ts = 0;
%Veamos el dato referente al radio de la celula

    R0 = 20*10^-6;  %Globulo rojo humano
    d = 5*10^-6;      %Anchura o espesor de un portaobjetos

%Los parametros que requiere el modelo para considerar la evolucion lineal en la variable Z sera:

    ns = (Ts - Text)/(Tint - Text);
    H1 = d/R0;
    
%Queremos obtener los valores de la funcion de temperatura para distintos valores de R y Z, barriendo un amplio
%margen del disco

    B=0;i=1;k=1;

    for Z=0:0.01:a
        for R=-b:0.01:b
        
            for n=1:1:N
                B = B + Am(n)*besselJ(0,betam(n)*R)*exp(-1*tau0*betam(n)^2);
            end
        
            f(k,i) = B*ns*Z/H1;
            i=i+1;
            B = 0;
        end
        k = k + 1;
        i=1;
    end
 
 %Una vez generada la carta devolvamos tambien los datos de R y Z por si se requiere alguna representacion adimensional.
 
    R=-b:0.01:b;
    Z=0:0.01:a;
    
    plot(R,H1*ones(size(R)));hold on;
    h = contour(R,Z,f,v);
    clabel(h);title('Carta R,Z en el el instante tau=0.07 supuesto perfil lineal en Z. Tint = 60ºC Text = -150ºC');